import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route, Navigate } from "react-router-dom";
import { ErrorBoundary } from "@/components/ErrorBoundary";
import { AppLayout } from "@/components/layout/AppLayout";
import { ProtectedFeature } from "@/components/dashboard/ProtectedFeature";
import { Suspense } from 'react';
import { LoadingSpinner } from '@/components/common/LoadingSpinner';
import { RoutePrefetcher } from '@/components/routing/RoutePrefetcher';
import { queryClient } from '@/config/queryClient';
import { SidebarProvider } from "@/components/ui/sidebar";
import { PerformanceMonitor } from '@/components/performance/PerformanceMonitor';
import { AuthProvider } from '@/contexts/AuthContext';
import ProtectedRoute from '@/components/ProtectedRoute';
import * as routes from '@/config/routes';
import WhatsApp from '@/pages/WhatsApp';

const App = () => {
  return (
    <ErrorBoundary>
      <TooltipProvider>
        <QueryClientProvider client={queryClient}>
          <Toaster />
          <Sonner />
          <PerformanceMonitor />
          <BrowserRouter>
            <AuthProvider>
              <RoutePrefetcher />
              <SidebarProvider>
                <div className="min-h-screen w-full">
                  <Suspense 
                    fallback={
                      <div className="flex items-center justify-center min-h-screen">
                        <LoadingSpinner size="lg" />
                      </div>
                    }
                  >
                    <Routes>
                      {/* Public Routes */}
                      <Route path="/" element={<routes.LandingPage />} />
                      <Route path="/index" element={<Navigate to="/" replace />} />
                      <Route path="/auth" element={<routes.Auth />} />
                      
                      {/* Handle Stripe return */}
                      <Route path="/stripe/return" element={<Navigate to="/billing" replace />} />
                      <Route path="/stripe/cancel" element={<Navigate to="/pricing" replace />} />
                      
                      <Route path="/pricing" element={
                        <AppLayout>
                          <routes.Pricing />
                        </AppLayout>
                      } />
                      <Route path="/about" element={<routes.About />} />
                      
                      {/* Add AI Images and Content Routes */}
                      <Route path="/ai-images" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.AIImages />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      <Route path="/content" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.Content />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      
                      {/* Existing routes */}
                      <Route path="/billing" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.Billing />
                          </AppLayout>
                        </ProtectedRoute>
                      } />

                      {/* Existing routes */}
                      <Route path="/onboarding" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.Onboarding />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      
                      <Route path="/dashboard/brand" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.BrandDashboard />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      <Route path="/sentiment" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <ProtectedFeature requiredTier="growth">
                              <routes.Sentiment />
                            </ProtectedFeature>
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      <Route path="/integrations" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <ProtectedFeature requiredTier="growth">
                              <routes.Integrations />
                            </ProtectedFeature>
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      
                      {/* Creator Routes */}
                      <Route path="/dashboard/creator" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.CreatorDashboard />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      <Route path="/brands" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.Brands />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      <Route path="/campaigns" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.Campaigns />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      
                      {/* Investor Routes */}
                      <Route path="/dashboard/investor" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.InvestorDashboard />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      <Route path="/deals" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.Deals />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      <Route path="/portfolio" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.Portfolio />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      
                      {/* Common Protected Routes */}
                      <Route path="/profile" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.Profile />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      <Route path="/settings" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.Settings />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      <Route path="/messages" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.Messages />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      <Route path="/notifications" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.Notifications />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      <Route path="/creators" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.Creators />
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      <Route path="/investment" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <routes.Investment />
                          </AppLayout>
                        </ProtectedRoute>
                      } />

                      {/* AI Writer Routes */}
                      <Route path="/ai-writer" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <ProtectedFeature requiredTier="growth">
                              <routes.AIWriter />
                            </ProtectedFeature>
                          </AppLayout>
                        </ProtectedRoute>
                      } />
                      <Route path="/ai-writer/setup" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <ProtectedFeature requiredTier="growth">
                              <routes.AIWriterSetup />
                            </ProtectedFeature>
                          </AppLayout>
                        </ProtectedRoute>
                      } />

                      <Route path="/whatsapp" element={
                        <ProtectedRoute>
                          <AppLayout>
                            <ProtectedFeature requiredTier="growth">
                              <WhatsApp />
                            </ProtectedFeature>
                          </AppLayout>
                        </ProtectedRoute>
                      } />

                      {/* 404 Route - Must be last */}
                      <Route path="*" element={<routes.NotFound />} />
                    </Routes>
                  </Suspense>
                </div>
              </SidebarProvider>
            </AuthProvider>
          </BrowserRouter>
        </QueryClientProvider>
      </TooltipProvider>
    </ErrorBoundary>
  );
};

export default App;
